@@ -1,5 +1,9 @@
 # flake8: noqa: F401
-from django_large_image.rest.standalone import ListColormapsView, ListTileSourcesView
+from django_large_image.rest.standalone import (
+    ListAvailableFormatsView,
+    ListColormapsView,
+    ListTileSourcesView,
+)
 from django_large_image.rest.viewsets import (
     LargeImageDetailMixin,
     LargeImageFileDetailMixin,
